// src/components/Boxes.js
import React, { useEffect, useState } from 'react';
import { Container, Button, TextField, Table, TableBody, TableCell, TableContainer, TableHead, TableRow } from '@mui/material';
import { Delete as DeleteIcon } from '@mui/icons-material';
import { Link as RouterLink } from 'react-router-dom'; // Import Link from react-router-dom
import axios from 'axios';
import { PRIMARY_COLOR, SECONDARY_COLOR } from '../App';

export default function Boxes({ token }) {
  const [boxes, setBoxes] = useState([]);
  const [newBoxName, setNewBoxName] = useState('');
  const apiUrl = `${process.env.REACT_APP_API_URL}/boxes`; 

  const debugApi = () => {
    if (process.env.DEBUG_API) {
      console.log("URL is " + apiUrl);
    }
  };
  debugApi();

  useEffect(() => {
    //console.log('Token:' + token);
    axios.get(`${process.env.REACT_APP_API_URL}/boxes`, {
      headers: { Authorization: `Bearer ${token}` }
    }).then(response => {
      setBoxes(response.data);
    });
  }, [token]);

  // Log boxes state changes outside the useEffect
  useEffect(() => {
    //console.log('Boxes updated:', boxes);
  }, [boxes]); 

  const handleCreateBox = () => {
    axios.post(`${process.env.REACT_APP_API_URL}/boxes`, { name: newBoxName }, {
      headers: { Authorization: `Bearer ${token}` }
    }).then(response => {
      setBoxes([...boxes, response.data]);
      setNewBoxName('');
    });
  };

  const handleDeleteBox = (id) => {
    axios.delete(`${process.env.REACT_APP_API_URL}/boxes/${id}`, {
      headers: { Authorization: `Bearer ${token}` }
    }).then(() => {
      setBoxes(boxes.filter(box => box.id !== id));
    });
  };

  return (
    <Container>

      <TableContainer>
        <Table>
          <TableHead>
            <TableRow>
              <TableCell>Box Name</TableCell>
              <TableCell>Actions</TableCell>
            </TableRow>
          </TableHead>
          <TableBody>
            {boxes.map((box) => (
              <TableRow key={box.ID}>
                <TableCell>
                  <RouterLink to={`/boxes/${box.ID}/items`} state={{ boxName: box.name, boxID: box.ID }}>
                    {box.name}
                  </RouterLink>
                </TableCell>
                <TableCell>
                  <Button onClick={() => handleDeleteBox(box.ID)} startIcon={<DeleteIcon />}>
                    Delete
                  </Button>
                </TableCell>
              </TableRow>
            ))}
          </TableBody>
        </Table>
      </TableContainer>
      <TextField
        label="New Box"
        variant="outlined"
        fullWidth
        value={newBoxName}
        onChange={(e) => setNewBoxName(e.target.value)}
      />
      <Button sx={{ backgroundColor: PRIMARY_COLOR, borderBottom: '1px solid', borderColor: '#444', color: SECONDARY_COLOR }} variant="contained" color="primary" onClick={handleCreateBox}>
        Add Box
      </Button>
    </Container>
  );
}